==> Tree-From-Text-0.020.tar.gz: Tree-From-Text-0.020/lib/Tree/From/Text.pm <==
package Tree::From::Text;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-02-04'; # DATE
our $DIST = 'Tree-From-Text'; # DIST
our $VERSION = '0.020'; # VERSION

1;
# ABSTRACT: Build a tree object from text

__END__

=pod

=encoding UTF-8

=head1 NAME

Tree::From::Text - Build a tree object from text

=head1 VERSION

This document describes version 0.020 of Tree::From::Text (from Perl distribution Tree-From-Text), released on 2020-02-04.

=head1 DESCRIPTION

This distribution contains several modules for convenient construction of tree
object from text:

=over

=item * L<Tree::From::Text>

=item * L<Tree::From::TextLines>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Tree-From-Text>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Tree-FromText>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree-From-Text>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

Other modules to create tree: L<Tree::From::Struct>, L<Tree::Create::Callback>,
L<Tree::Create::Size>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Tree-From-Text-0.021.tar.gz: Tree-From-Text-0.021/lib/Tree/From/Text.pm <==
package Tree::From::Text;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-05-06'; # DATE
our $DIST = 'Tree-From-Text'; # DIST
our $VERSION = '0.021'; # VERSION

1;
# ABSTRACT: Build a tree object from text

__END__

=pod

=encoding UTF-8

=head1 NAME

Tree::From::Text - Build a tree object from text

=head1 VERSION

This document describes version 0.021 of Tree::From::Text (from Perl distribution Tree-From-Text), released on 2021-05-06.

=head1 DESCRIPTION

This distribution contains several modules for convenient construction of tree
object from text:

=over

=item * L<Tree::From::Text>

=item * L<Tree::From::TextLines>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Tree-From-Text>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Tree-From-Text>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Tree-From-Text/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

Other modules to create tree: L<Tree::From::Struct>, L<Tree::From::ObjArray>,
L<Tree::Create::Callback>, L<Tree::Create::Size>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
